Performs trajectories runs for several k and several random
start replicates within k. Returns a data frame with a Rand Index
comparison between all pairs of clusterings. This data frame is typically
input to rand_plot to produce a heat map with the Adjusted
Rand Index results.
clustra_rand(
data,
k,
starts = "random",
mccores = 1,
replicates = 10,
maxdf = 30,
conv = c(10, 0),
save = FALSE,
verbose = FALSE
)See allpair_RandIndex.
The data (see clustra description).
Vector of k values to try.
See clustra.
Number of cores for replicate parallelism via mclapply.
Number of replicates for each k.
Fitting parameters. See link{trajectories}.
Fitting parameters. See link{trajectories}.
Logical. When TRUE, save all results as file results.Rdata.
Logical. When TRUE, information about each run of clustra (but not iterations within) is printed.