bam.Fits a thin plate spline to a single group (one list element) in data with
bam. Uses data from only one group rather than a
zero weights approach. Zero weights would result in
incorrect crossvalidation sampling.
tps_g(g, data, maxdf, nthreads)Returns an object of class "gam". See bam value.
If group data has zero rows, NULL is returned instead.
Integer group number.
A list of group-separated data using lapply with
data.table::copy(data[group == g]) from original data in
clustra description.
See trajectories description.
Controls bam threads.